# Reweave
Reweave is an experimental AI video creation toolkit. 

I plan on adding more workflows to the video builder workflows with time which outputs the final video. This serves as experimental place to mix and match different tools out there before improving the project structure.


### Candidate features
#### Library workflows
1. manim based math animations
2. python data visualization workflows supporting matplotlib, seaborn and other animations
3. nvidia warp workflows

#### Automation features
1. Multi agent workflows
 

 ### Connect with me
 Feel free to contact me if you have any questions or suggestions. You can connect with me at chandresh.code [at] gmail.com